@@ -6,19 +6,21 @@
 
 #include "knotificationplugin.h"
 
+class KNotificationPluginPrivate
+{
+};
+
 KNotificationPlugin::KNotificationPlugin(QObject *parent, const QVariantList &args)
-    : QObject(parent),
-      d(nullptr)
+    : QObject(parent)
+    , d(nullptr)
 {
     Q_UNUSED(args);
 }
 
-
 KNotificationPlugin::~KNotificationPlugin()
 {
 }
 
-
 void KNotificationPlugin::update(KNotification *notification, KNotifyConfig *config)
 {
     Q_UNUSED(notification);
@@ -27,11 +29,12 @@ void KNotificationPlugin::update(KNotification *notification, KNotifyConfig *con
 
 void KNotificationPlugin::close(KNotification *notification)
 {
-    emit finished(notification);
+    Q_EMIT finished(notification);
 }
 
 void KNotificationPlugin::finish(KNotification *notification)
 {
-    emit finished(notification);
+    Q_EMIT finished(notification);
 }
 
+#include "moc_knotificationplugin.cpp"
