@@ -5,7 +5,6 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-
 #ifndef NOTIFYBYAUDIO_H
 #define NOTIFYBYAUDIO_H
 
@@ -13,7 +12,8 @@
 
 #include <phonon/MediaObject>
 
-namespace Phonon {
+namespace Phonon
+{
 // class MediaObject;
 class MediaSource;
 class AudioOutput;
@@ -29,7 +29,10 @@ public:
     explicit NotifyByAudio(QObject *parent = nullptr);
     ~NotifyByAudio() override;
 
-    QString optionName() override { return QStringLiteral("Sound"); }
+    QString optionName() override
+    {
+        return QStringLiteral("Sound");
+    }
     void notify(KNotification *notification, KNotifyConfig *config) override;
     void close(KNotification *notification) override;
 
@@ -38,12 +41,11 @@ private Q_SLOTS:
     void onAudioSourceChanged(const Phonon::MediaSource &source);
     void stateChanged(Phonon::State newState, Phonon::State oldState);
 
-
 private:
     void finishNotification(KNotification *notification, Phonon::MediaObject *m);
 
-    QList<Phonon::MediaObject*> m_reusablePhonons;
-    QHash<Phonon::MediaObject*, KNotification*> m_notifications;
+    QList<Phonon::MediaObject *> m_reusablePhonons;
+    QHash<Phonon::MediaObject *, KNotification *> m_notifications;
     Phonon::AudioOutput *m_audioOutput;
 };
 
