@@ -124,10 +124,7 @@ NotifyByPortal::NotifyByPortal(QObject *parent)
     connect(watcher, &QDBusServiceWatcher::serviceOwnerChanged, this, &NotifyByPortal::onServiceOwnerChanged);
 }
 
-NotifyByPortal::~NotifyByPortal()
-{
-    delete d;
-}
+NotifyByPortal::~NotifyByPortal() = default;
 
 void NotifyByPortal::notify(KNotification *notification, KNotifyConfig *notifyConfig)
 {
@@ -354,3 +351,5 @@ void NotifyByPortalPrivate::closePortalNotification(KNotification *notification)
         qCWarning(LOG_KNOTIFICATIONS) << "Failed to queue dbus message for closing a notification";
     }
 }
+
+#include "moc_notifybyportal.cpp"
